onlyFirst property
Indicate whether only the first matching substring should be replaced for each field.
Implementation
final bool onlyFirst;
Indicate whether only the first matching substring should be replaced for each field.
final bool onlyFirst;